Range

Struct Range 

pub struct Range<T> {
    pub start: usize,
    pub end: usize,
    /* private fields */
}
Wrapper that records the [start, end) input span its ranged value was parsed from.

Fields

start: usize

Byte offset where the ranged value started matching.

end: usize

Byte offset just past where the ranged value finished matching.

Implementations

Source

impl<T> Range<T>

pub fn new(start: usize, ranged: T, end: usize) -> Self

Construct a Range from an already-known span.

pub fn map<U>(self, f: impl FnOnce(T) -> U) -> Range<U>

Apply f to the ranged value, keeping the same span.

pub fn as_ref(&self) -> Range<&T>

Borrow the ranged value, keeping the same span.

Source

impl<T> Range<Option<T>>

pub fn transpose(self) -> Option<Range<T>>

Swap Range<Option<T>> for Option<Range<T>>.

Source

impl<T, E> Range<Result<T, E>>

pub fn transpose(self) -> Result<Range<T>, E>

Swap Range<Result<T, E>> for Result<Range<T>, E>.